TMTC Commander Core
======================

This is a small Python framework targeted towards the testing of remote systems like satellites
and rovers. It simplifies sending and receiving TMTCs (Telemetry and Telecommands)
and testing via different communication interfaces. This tool can be
used either as a command line tool or as a GUI tool which requires a PyQt5 installation.
This package also has dedicated support to send and receive ECSS PUS packets or other generic
CCSDS packets.

This framework started as a small application for the
`SOURCE <https://www.ksat-stuttgart.de/en/our-missions/source/>`_ project to test the on-board
software but has evolved to be more generic and easily adaptable to new projects.

Other pages (online)

- `project page on GitHub`_
- This page, when viewed online is at https://tmtccmd.readthedocs.io/en/latest/

.. _`project page on GitHub`: https://github.com/robamu-org/tmtccmd

Contents
========

.. toctree::
   :maxdepth: 2
   
   introduction
   gettingstarted
   communication
   cfdp 
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
